@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -129,6 +130,7 @@ class NUGroupKeyEncryptionProfile(NURESTObject):
         self._sek_payload_encryption_bc_algorithm = None
         self._sek_payload_encryption_key_length = None
         self._sek_payload_signing_algorithm = None
+        self._dr_seed_lifetime = None
         self._name = None
         self._last_updated_by = None
         self._seed_generation_interval = None
@@ -145,6 +147,7 @@ class NUGroupKeyEncryptionProfile(NURESTObject):
         self._traffic_authentication_algorithm = None
         self._traffic_encryption_algorithm = None
         self._traffic_encryption_key_lifetime = None
+        self._associated_enterprise_id = None
         self._external_id = None
         
         self.expose_attribute(local_name="sek_generation_interval", remote_name="SEKGenerationInterval", attribute_type=int, is_required=False, is_unique=False)
@@ -153,6 +156,7 @@ class NUGroupKeyEncryptionProfile(NURESTObject):
         self.expose_attribute(local_name="sek_payload_encryption_bc_algorithm", remote_name="SEKPayloadEncryptionBCAlgorithm", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="sek_payload_encryption_key_length", remote_name="SEKPayloadEncryptionKeyLength", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="sek_payload_signing_algorithm", remote_name="SEKPayloadSigningAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'SHA1withRSA', u'SHA224withRSA', u'SHA256withRSA', u'SHA384withRSA', u'SHA512withRSA'])
+        self.expose_attribute(local_name="dr_seed_lifetime", remote_name="DRSeedLifetime", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="seed_generation_interval", remote_name="seedGenerationInterval", attribute_type=int, is_required=False, is_unique=False)
@@ -169,6 +173,7 @@ class NUGroupKeyEncryptionProfile(NURESTObject):
         self.expose_attribute(local_name="traffic_authentication_algorithm", remote_name="trafficAuthenticationAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'HMAC_MD5', u'HMAC_SHA1', u'HMAC_SHA256', u'HMAC_SHA384', u'HMAC_SHA512'])
         self.expose_attribute(local_name="traffic_encryption_algorithm", remote_name="trafficEncryptionAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'AES_128_CBC', u'AES_192_CBC', u'AES_256_CBC', u'TRIPLE_DES_CBC'])
         self.expose_attribute(local_name="traffic_encryption_key_lifetime", remote_name="trafficEncryptionKeyLifetime", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_enterprise_id", remote_name="associatedEnterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -347,6 +352,33 @@ class NUGroupKeyEncryptionProfile(NURESTObject):
         self._sek_payload_signing_algorithm = value
 
     
+    @property
+    def dr_seed_lifetime(self):
+        """ Get dr_seed_lifetime value.
+
+            Notes:
+                DR Seed Lifetime in seconds
+
+                
+                This attribute is named `DRSeedLifetime` in VSD API.
+                
+        """
+        return self._dr_seed_lifetime
+
+    @dr_seed_lifetime.setter
+    def dr_seed_lifetime(self, value):
+        """ Set dr_seed_lifetime value.
+
+            Notes:
+                DR Seed Lifetime in seconds
+
+                
+                This attribute is named `DRSeedLifetime` in VSD API.
+                
+        """
+        self._dr_seed_lifetime = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -771,6 +803,33 @@ class NUGroupKeyEncryptionProfile(NURESTObject):
         self._traffic_encryption_key_lifetime = value
 
     
+    @property
+    def associated_enterprise_id(self):
+        """ Get associated_enterprise_id value.
+
+            Notes:
+                The ID of the associated Enterprise
+
+                
+                This attribute is named `associatedEnterpriseID` in VSD API.
+                
+        """
+        return self._associated_enterprise_id
+
+    @associated_enterprise_id.setter
+    def associated_enterprise_id(self, value):
+        """ Set associated_enterprise_id value.
+
+            Notes:
+                The ID of the associated Enterprise
+
+                
+                This attribute is named `associatedEnterpriseID` in VSD API.
+                
+        """
+        self._associated_enterprise_id = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
