@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -45,7 +46,7 @@ class NUIngressAdvFwdTemplate(NURESTObject):
     """ Represents a IngressAdvFwdTemplate in the VSD
 
         Notes:
-            Defines the template for an Ingress Advanced Forwarding.
+            Create a table for ingress forwarding policy rules. These include flow redirect rules and forwarding class override rules.
     """
 
     __rest_name__ = "ingressadvfwdtemplate"
@@ -90,6 +91,8 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         self._name = None
         self._last_updated_by = None
         self._active = None
+        self._default_allow_ip = None
+        self._default_allow_non_ip = None
         self._description = None
         self._entity_scope = None
         self._policy_state = None
@@ -102,6 +105,8 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="active", remote_name="active", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="default_allow_ip", remote_name="defaultAllowIP", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="default_allow_non_ip", remote_name="defaultAllowNonIP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="policy_state", remote_name="policyState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DRAFT', u'LIVE'])
@@ -204,6 +209,60 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         self._active = value
 
     
+    @property
+    def default_allow_ip(self):
+        """ Get default_allow_ip value.
+
+            Notes:
+                If enabled a default ACL of Allow All is added as the last entry in the list of ACL entries
+
+                
+                This attribute is named `defaultAllowIP` in VSD API.
+                
+        """
+        return self._default_allow_ip
+
+    @default_allow_ip.setter
+    def default_allow_ip(self, value):
+        """ Set default_allow_ip value.
+
+            Notes:
+                If enabled a default ACL of Allow All is added as the last entry in the list of ACL entries
+
+                
+                This attribute is named `defaultAllowIP` in VSD API.
+                
+        """
+        self._default_allow_ip = value
+
+    
+    @property
+    def default_allow_non_ip(self):
+        """ Get default_allow_non_ip value.
+
+            Notes:
+                If enabled, non ip traffic will be dropped
+
+                
+                This attribute is named `defaultAllowNonIP` in VSD API.
+                
+        """
+        return self._default_allow_non_ip
+
+    @default_allow_non_ip.setter
+    def default_allow_non_ip(self, value):
+        """ Set default_allow_non_ip value.
+
+            Notes:
+                If enabled, non ip traffic will be dropped
+
+                
+                This attribute is named `defaultAllowNonIP` in VSD API.
+                
+        """
+        self._default_allow_non_ip = value
+
+    
     @property
     def description(self):
         """ Get description value.
@@ -259,7 +318,7 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         """ Get policy_state value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `policyState` in VSD API.
@@ -272,7 +331,7 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         """ Set policy_state value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `policyState` in VSD API.
@@ -309,7 +368,7 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         """ Get priority_type value.
 
             Notes:
-                
+                Possible values: TOP, BOTTOM or NONE. TOP and BOTTOM ACL policies can only be defined and managed on the template level, NONE can be used on both the template and instantiated level. These allow for careful control of ACL priority handling.
 
                 
                 This attribute is named `priorityType` in VSD API.
@@ -322,7 +381,7 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         """ Set priority_type value.
 
             Notes:
-                
+                Possible values: TOP, BOTTOM or NONE. TOP and BOTTOM ACL policies can only be defined and managed on the template level, NONE can be used on both the template and instantiated level. These allow for careful control of ACL priority handling.
 
                 
                 This attribute is named `priorityType` in VSD API.
@@ -363,7 +422,7 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         """ Get auto_generate_priority value.
 
             Notes:
-                This option affects how ACL entry priorities are generated when not specified. If "false", the priority is generated by incrementing the current highest priority by 100. If "true", a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
+                This option affects how ACL entry priorities are generated when not specified. If 'false', the priority is generated by incrementing the current highest priority by 100. If 'true', a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
 
                 
                 This attribute is named `autoGeneratePriority` in VSD API.
@@ -376,7 +435,7 @@ class NUIngressAdvFwdTemplate(NURESTObject):
         """ Set auto_generate_priority value.
 
             Notes:
-                This option affects how ACL entry priorities are generated when not specified. If "false", the priority is generated by incrementing the current highest priority by 100. If "true", a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
+                This option affects how ACL entry priorities are generated when not specified. If 'false', the priority is generated by incrementing the current highest priority by 100. If 'true', a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
 
                 
                 This attribute is named `autoGeneratePriority` in VSD API.
