@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,10 @@
 
 
 
+
+from .fetchers import NUDeploymentFailuresFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -53,8 +57,12 @@ class NUStaticRoute(NURESTObject):
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_TYPE_OVERLAY_ADDRESS_TRANSLATION = "OVERLAY_ADDRESS_TRANSLATION"
+    
     CONST_TYPE_OVERLAY = "OVERLAY"
     
+    CONST_TYPE_NETCONF = "NETCONF"
+    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_IP_TYPE_IPV6 = "IPV6"
@@ -63,8 +71,6 @@ class NUStaticRoute(NURESTObject):
     
     CONST_TYPE_EXIT_DOMAIN = "EXIT_DOMAIN"
     
-    CONST_IP_TYPE_DUALSTACK = "DUALSTACK"
-    
     
 
     def __init__(self, **kwargs):
@@ -84,32 +90,43 @@ class NUStaticRoute(NURESTObject):
 
         # Read/Write Attributes
         
+        self._bfd_enabled = None
         self._ip_type = None
         self._ipv6_address = None
         self._last_updated_by = None
         self._address = None
         self._netmask = None
         self._next_hop_ip = None
+        self._black_hole_enabled = None
         self._entity_scope = None
         self._route_distinguisher = None
+        self._associated_gateway_ids = None
+        self._associated_subnet_id = None
         self._external_id = None
         self._type = None
         
-        self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DUALSTACK', u'IPV4', u'IPV6'])
+        self.expose_attribute(local_name="bfd_enabled", remote_name="BFDEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'IPV4', u'IPV6'])
         self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=True, is_unique=False)
-        self.expose_attribute(local_name="netmask", remote_name="netmask", attribute_type=str, is_required=True, is_unique=False)
-        self.expose_attribute(local_name="next_hop_ip", remote_name="nextHopIp", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="netmask", remote_name="netmask", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="next_hop_ip", remote_name="nextHopIp", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="black_hole_enabled", remote_name="blackHoleEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="route_distinguisher", remote_name="routeDistinguisher", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_gateway_ids", remote_name="associatedGatewayIDs", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_subnet_id", remote_name="associatedSubnetID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
-        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'EXIT_DOMAIN', u'OVERLAY'])
+        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=False, is_unique=False, choices=[u'EXIT_DOMAIN', u'NETCONF', u'OVERLAY', u'OVERLAY_ADDRESS_TRANSLATION'])
         
 
         # Fetchers
         
         
+        self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -123,6 +140,33 @@ class NUStaticRoute(NURESTObject):
 
     # Properties
     
+    @property
+    def bfd_enabled(self):
+        """ Get bfd_enabled value.
+
+            Notes:
+                Enable or disable Bidirectional Forwarding Detection for this static route
+
+                
+                This attribute is named `BFDEnabled` in VSD API.
+                
+        """
+        return self._bfd_enabled
+
+    @bfd_enabled.setter
+    def bfd_enabled(self, value):
+        """ Set bfd_enabled value.
+
+            Notes:
+                Enable or disable Bidirectional Forwarding Detection for this static route
+
+                
+                This attribute is named `BFDEnabled` in VSD API.
+                
+        """
+        self._bfd_enabled = value
+
+    
     @property
     def ip_type(self):
         """ Get ip_type value.
@@ -277,6 +321,33 @@ class NUStaticRoute(NURESTObject):
         self._next_hop_ip = value
 
     
+    @property
+    def black_hole_enabled(self):
+        """ Get black_hole_enabled value.
+
+            Notes:
+                Indicates if this is a black hole static route. Applicable only when the static route type is 'NETCONF'.
+
+                
+                This attribute is named `blackHoleEnabled` in VSD API.
+                
+        """
+        return self._black_hole_enabled
+
+    @black_hole_enabled.setter
+    def black_hole_enabled(self, value):
+        """ Set black_hole_enabled value.
+
+            Notes:
+                Indicates if this is a black hole static route. Applicable only when the static route type is 'NETCONF'.
+
+                
+                This attribute is named `blackHoleEnabled` in VSD API.
+                
+        """
+        self._black_hole_enabled = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -331,6 +402,60 @@ class NUStaticRoute(NURESTObject):
         self._route_distinguisher = value
 
     
+    @property
+    def associated_gateway_ids(self):
+        """ Get associated_gateway_ids value.
+
+            Notes:
+                List of associated gateway IDs for static route, returned as a JSON list of strings
+
+                
+                This attribute is named `associatedGatewayIDs` in VSD API.
+                
+        """
+        return self._associated_gateway_ids
+
+    @associated_gateway_ids.setter
+    def associated_gateway_ids(self, value):
+        """ Set associated_gateway_ids value.
+
+            Notes:
+                List of associated gateway IDs for static route, returned as a JSON list of strings
+
+                
+                This attribute is named `associatedGatewayIDs` in VSD API.
+                
+        """
+        self._associated_gateway_ids = value
+
+    
+    @property
+    def associated_subnet_id(self):
+        """ Get associated_subnet_id value.
+
+            Notes:
+                UUID of Do Not Advertise Subnet
+
+                
+                This attribute is named `associatedSubnetID` in VSD API.
+                
+        """
+        return self._associated_subnet_id
+
+    @associated_subnet_id.setter
+    def associated_subnet_id(self, value):
+        """ Set associated_subnet_id value.
+
+            Notes:
+                UUID of Do Not Advertise Subnet
+
+                
+                This attribute is named `associatedSubnetID` in VSD API.
+                
+        """
+        self._associated_subnet_id = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
