@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -57,6 +58,9 @@ from .fetchers import NUHSCsFetcher
 from .fetchers import NUVSCsFetcher
 
 
+from .fetchers import NUStatisticsFetcher
+
+
 from .fetchers import NUMultiNICVPortsFetcher
 
 
@@ -86,6 +90,8 @@ class NUVRS(NURESTObject):
     
     CONST_PERSONALITY_NUAGE_210_WBX_32_Q = "NUAGE_210_WBX_32_Q"
     
+    CONST_PERSONALITY_NSGDUC = "NSGDUC"
+    
     CONST_PERSONALITY_NONE = "NONE"
     
     CONST_CLUSTER_NODE_ROLE_NONE = "NONE"
@@ -114,6 +120,8 @@ class NUVRS(NURESTObject):
     
     CONST_JSONRPC_CONNECTION_STATE_ADMIN_DOWN = "ADMIN_DOWN"
     
+    CONST_PERSONALITY_VRSB = "VRSB"
+    
     CONST_STATUS_UP = "UP"
     
     CONST_PERSONALITY_NUAGE_210_WBX_48_S = "NUAGE_210_WBX_48_S"
@@ -138,6 +146,8 @@ class NUVRS(NURESTObject):
     
     CONST_LICENSED_STATE_UNLICENSED = "UNLICENSED"
     
+    CONST_PERSONALITY_NSGBR = "NSGBR"
+    
     
 
     def __init__(self, **kwargs):
@@ -166,6 +176,7 @@ class NUVRS(NURESTObject):
         self._last_event_timestamp = None
         self._last_state_change = None
         self._last_updated_by = None
+        self._gateway_uuid = None
         self._db_synced = None
         self._address = None
         self._peak_cpuusage = None
@@ -216,12 +227,13 @@ class NUVRS(NURESTObject):
         self.expose_attribute(local_name="last_event_timestamp", remote_name="lastEventTimestamp", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_state_change", remote_name="lastStateChange", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="gateway_uuid", remote_name="gatewayUUID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="db_synced", remote_name="dbSynced", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak_cpuusage", remote_name="peakCPUUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak_memory_usage", remote_name="peakMemoryUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peer", remote_name="peer", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'HARDWARE_VTEP', u'NONE', u'NSG', u'NUAGE_210_WBX_32_Q', u'NUAGE_210_WBX_48_S', u'VRS', u'VRSG'])
+        self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'HARDWARE_VTEP', u'NONE', u'NSG', u'NSGBR', u'NSGDUC', u'NUAGE_210_WBX_32_Q', u'NUAGE_210_WBX_48_S', u'VRS', u'VRSB', u'VRSG'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="messages", remote_name="messages", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="revert_behavior_enabled", remote_name="revertBehaviorEnabled", attribute_type=bool, is_required=False, is_unique=False)
@@ -291,6 +303,9 @@ class NUVRS(NURESTObject):
         self.vscs = NUVSCsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.statistics = NUStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.multi_nic_vports = NUMultiNICVPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -540,6 +555,33 @@ class NUVRS(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def gateway_uuid(self):
+        """ Get gateway_uuid value.
+
+            Notes:
+                UUID of the gateway instance
+
+                
+                This attribute is named `gatewayUUID` in VSD API.
+                
+        """
+        return self._gateway_uuid
+
+    @gateway_uuid.setter
+    def gateway_uuid(self, value):
+        """ Set gateway_uuid value.
+
+            Notes:
+                UUID of the gateway instance
+
+                
+                This attribute is named `gatewayUUID` in VSD API.
+                
+        """
+        self._gateway_uuid = value
+
+    
     @property
     def db_synced(self):
         """ Get db_synced value.
