@@ -28,6 +28,9 @@
 
 
 
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -176,6 +179,9 @@ class NUApplication(NURESTObject):
         # Fetchers
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -455,7 +461,7 @@ class NUApplication(NURESTObject):
         """ Get destination_port value.
 
             Notes:
-                value should be either * or single port number or maximum 5 ranges comma separated. 
+                value should be either * or single port number or maximum 5 ranges comma separated.
 
                 
                 This attribute is named `destinationPort` in VSD API.
@@ -468,7 +474,7 @@ class NUApplication(NURESTObject):
         """ Set destination_port value.
 
             Notes:
-                value should be either * or single port number or maximum 5 ranges comma separated. 
+                value should be either * or single port number or maximum 5 ranges comma separated.
 
                 
                 This attribute is named `destinationPort` in VSD API.
@@ -725,7 +731,7 @@ class NUApplication(NURESTObject):
         """ Get source_port value.
 
             Notes:
-                source Port ,value should be either * or single port number or maximum 5 ranges comma separated. 
+                source Port ,value should be either * or single port number or maximum 5 ranges comma separated.
 
                 
                 This attribute is named `sourcePort` in VSD API.
@@ -738,7 +744,7 @@ class NUApplication(NURESTObject):
         """ Set source_port value.
 
             Notes:
-                source Port ,value should be either * or single port number or maximum 5 ranges comma separated. 
+                source Port ,value should be either * or single port number or maximum 5 ranges comma separated.
 
                 
                 This attribute is named `sourcePort` in VSD API.
