@@ -28,6 +28,9 @@
 
 
 
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -80,6 +83,7 @@ class NUMACFilterProfile(NURESTObject):
         self._entity_scope = None
         self._creation_date = None
         self._assoc_entity_type = None
+        self._customer_id = None
         self._owner = None
         self._external_id = None
         
@@ -91,6 +95,7 @@ class NUMACFilterProfile(NURESTObject):
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="assoc_entity_type", remote_name="assocEntityType", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
@@ -98,6 +103,9 @@ class NUMACFilterProfile(NURESTObject):
         # Fetchers
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -316,6 +324,33 @@ class NUMACFilterProfile(NURESTObject):
         self._assoc_entity_type = value
 
     
+    @property
+    def customer_id(self):
+        """ Get customer_id value.
+
+            Notes:
+                The customer ID given to parent enterprise. This is used by Netconf/Config manager.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        return self._customer_id
+
+    @customer_id.setter
+    def customer_id(self, value):
+        """ Set customer_id value.
+
+            Notes:
+                The customer ID given to parent enterprise. This is used by Netconf/Config manager.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        self._customer_id = value
+
+    
     @property
     def owner(self):
         """ Get owner value.
