@@ -243,6 +243,8 @@ class NUNSGateway(NURESTObject):
     
     CONST_TUNNEL_SHAPING_DISABLED = "DISABLED"
     
+    CONST_NETWORK_ACCELERATION_TP_AWARE = "TP_AWARE"
+    
     CONST_ZFB_MATCH_ATTRIBUTE_SERIAL_NUMBER = "SERIAL_NUMBER"
     
     CONST_NETWORK_ACCELERATION_SESSION_OPTIMIZED = "SESSION_OPTIMIZED"
@@ -403,7 +405,7 @@ class NUNSGateway(NURESTObject):
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False, choices=[u'NSG', u'NSGBR', u'NSGDUC'])
         self.expose_attribute(local_name="cert_validity_days", remote_name="certValidityDays", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="network_acceleration", remote_name="networkAcceleration", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PERFORMANCE', u'SESSION_OPTIMIZED', u'VNF_AWARE'])
+        self.expose_attribute(local_name="network_acceleration", remote_name="networkAcceleration", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'PERFORMANCE', u'SESSION_OPTIMIZED', u'TP_AWARE', u'VNF_AWARE'])
         self.expose_attribute(local_name="threat_prevention_enabled", remote_name="threatPreventionEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="libraries", remote_name="libraries", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
