@@ -110,6 +110,7 @@ class NUVSC(NURESTObject):
         self._addresses = None
         self._peak_cpuusage = None
         self._peak_memory_usage = None
+        self._secondary_role_count = None
         self._description = None
         self._messages = None
         self._disks = None
@@ -120,9 +121,11 @@ class NUVSC(NURESTObject):
         self._location = None
         self._communication_id = None
         self._creation_date = None
+        self._primary_role_count = None
         self._product_version = None
         self._vsds = None
         self._status = None
+        self._number_of_inactive_gateways = None
         self._current_cpuusage = None
         self._current_memory_usage = None
         self._average_cpuusage = None
@@ -138,6 +141,7 @@ class NUVSC(NURESTObject):
         self.expose_attribute(local_name="addresses", remote_name="addresses", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak_cpuusage", remote_name="peakCPUUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak_memory_usage", remote_name="peakMemoryUsage", attribute_type=float, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="secondary_role_count", remote_name="secondaryRoleCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="messages", remote_name="messages", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="disks", remote_name="disks", attribute_type=list, is_required=False, is_unique=False)
@@ -148,9 +152,11 @@ class NUVSC(NURESTObject):
         self.expose_attribute(local_name="location", remote_name="location", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="communication_id", remote_name="communicationId", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="primary_role_count", remote_name="primaryRoleCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="product_version", remote_name="productVersion", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vsds", remote_name="vsds", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'ADMIN_DOWN', u'DOWN', u'UP'])
+        self.expose_attribute(local_name="number_of_inactive_gateways", remote_name="numberOfInactiveGateways", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="current_cpuusage", remote_name="currentCPUUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="current_memory_usage", remote_name="currentMemoryUsage", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="average_cpuusage", remote_name="averageCPUUsage", attribute_type=float, is_required=False, is_unique=False)
@@ -404,6 +410,33 @@ class NUVSC(NURESTObject):
         self._peak_memory_usage = value
 
     
+    @property
+    def secondary_role_count(self):
+        """ Get secondary_role_count value.
+
+            Notes:
+                Number of uplinks as secondary role.
+
+                
+                This attribute is named `secondaryRoleCount` in VSD API.
+                
+        """
+        return self._secondary_role_count
+
+    @secondary_role_count.setter
+    def secondary_role_count(self, value):
+        """ Set secondary_role_count value.
+
+            Notes:
+                Number of uplinks as secondary role.
+
+                
+                This attribute is named `secondaryRoleCount` in VSD API.
+                
+        """
+        self._secondary_role_count = value
+
+    
     @property
     def description(self):
         """ Get description value.
@@ -658,6 +691,33 @@ class NUVSC(NURESTObject):
         self._creation_date = value
 
     
+    @property
+    def primary_role_count(self):
+        """ Get primary_role_count value.
+
+            Notes:
+                Number of uplinks as primary role.
+
+                
+                This attribute is named `primaryRoleCount` in VSD API.
+                
+        """
+        return self._primary_role_count
+
+    @primary_role_count.setter
+    def primary_role_count(self, value):
+        """ Set primary_role_count value.
+
+            Notes:
+                Number of uplinks as primary role.
+
+                
+                This attribute is named `primaryRoleCount` in VSD API.
+                
+        """
+        self._primary_role_count = value
+
+    
     @property
     def product_version(self):
         """ Get product_version value.
@@ -731,6 +791,33 @@ class NUVSC(NURESTObject):
         self._status = value
 
     
+    @property
+    def number_of_inactive_gateways(self):
+        """ Get number_of_inactive_gateways value.
+
+            Notes:
+                Number of inactive Gateways.
+
+                
+                This attribute is named `numberOfInactiveGateways` in VSD API.
+                
+        """
+        return self._number_of_inactive_gateways
+
+    @number_of_inactive_gateways.setter
+    def number_of_inactive_gateways(self, value):
+        """ Set number_of_inactive_gateways value.
+
+            Notes:
+                Number of inactive Gateways.
+
+                
+                This attribute is named `numberOfInactiveGateways` in VSD API.
+                
+        """
+        self._number_of_inactive_gateways = value
+
+    
     @property
     def current_cpuusage(self):
         """ Get current_cpuusage value.
